==> haskell-th-utilities-0.2.0.1-14-i686.pkg.tar.xz: usr/share/haskell/register/haskell-th-utilities.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: th-utilities
version: 0.2.0.1
id: th-utilities-0.2.0.1-G1q29TS5Gp7G96RrRPp8pQ
key: th-utilities-0.2.0.1-G1q29TS5Gp7G96RrRPp8pQ
license: MIT
copyright: 2016 FP Complete
maintainer: Michael Sloan <sloan@fpcomplete.com>
homepage: https://github.com/fpco/th-utilities#readme
synopsis: Collection of useful functions for use with Template Haskell
category: Template Haskell
exposed: True
exposed-modules:
    TH.Derive TH.Derive.Storable TH.ReifySimple TH.RelativePaths
    TH.Utilities
hidden-modules: TH.Derive.Internal
abi: 0647826c90b958f2e2c6990c2c2b62c1
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/th-utilities-0.2.0.1
library-dirs: /usr/lib/ghc-8.0.2/site-local/th-utilities-0.2.0.1
dynamic-library-dirs: /usr/lib/i386-linux-ghc-8.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.2/th-utilities-0.2.0.1
hs-libraries: HSth-utilities-0.2.0.1-G1q29TS5Gp7G96RrRPp8pQ
depends:
    base-4.9.1.0 bytestring-0.10.8.1 containers-0.5.7.1
    directory-1.3.0.0 filepath-1.4.1.1
    primitive-0.6.2.0-4578caNkWQ54Gt1mxLF2Yh
    syb-0.6-IcoSwlPi2Nx4zSqMmorFPS template-haskell-2.11.1.0
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq
    th-orphans-0.13.3-AjSyqafunH7F0wdJIUkNrE
haddock-interfaces: /usr/share/doc/haskell-th-utilities/html/th-utilities.haddock
haddock-html: /usr/share/doc/haskell-th-utilities/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-th-utilities-0.2.0.1-15-i686.pkg.tar.xz: usr/share/haskell/register/haskell-th-utilities.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: th-utilities
version: 0.2.0.1
id: th-utilities-0.2.0.1-Fn9OLtGXSZ2CY7wvtO56XG
key: th-utilities-0.2.0.1-Fn9OLtGXSZ2CY7wvtO56XG
license: MIT
copyright: 2016 FP Complete
maintainer: Michael Sloan <sloan@fpcomplete.com>
homepage: https://github.com/fpco/th-utilities#readme
synopsis: Collection of useful functions for use with Template Haskell
category: Template Haskell
exposed: True
exposed-modules:
    TH.Derive TH.Derive.Storable TH.ReifySimple TH.RelativePaths
    TH.Utilities
hidden-modules: TH.Derive.Internal
abi: 41953575ad54c49f48d3385e9d074b66
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/th-utilities-0.2.0.1
library-dirs: /usr/lib/ghc-8.0.2/site-local/th-utilities-0.2.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/th-utilities-0.2.0.1
hs-libraries: HSth-utilities-0.2.0.1-Fn9OLtGXSZ2CY7wvtO56XG
depends:
    base-4.9.1.0 bytestring-0.10.8.1 containers-0.5.7.1
    directory-1.3.0.0 filepath-1.4.1.1
    primitive-0.6.2.0-4578caNkWQ54Gt1mxLF2Yh
    syb-0.6-IcoSwlPi2Nx4zSqMmorFPS template-haskell-2.11.1.0
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq
    th-orphans-0.13.3-1N7FgGBrfp4F9N2gYS687g
haddock-interfaces: /usr/share/doc/haskell-th-utilities/html/th-utilities.haddock
haddock-html: /usr/share/doc/haskell-th-utilities/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
